/*
Morning Routine IOT
  I created a sketch that collects data and produces information about the environment,
  uploads the data to the Internet and allows to view them in the blynk app.

  This sketch Will help you with your morning routine, by collecting data and produces information
  to you.

*/



#define BLYNK_PRINT SerialUSB
#define BLYNK_DEBUG SerialUSB
#define EspSerial Serial1
#define ESP8266_BAUD 115200
#define ROTATION_RATE   30
#include <ESP8266_Lib.h>
#include <BlynkSimpleShieldEsp8266.h>
#include <Adafruit_CircuitPlayground.h>
#include "pitches.h"
#include <Wire.h>
#include <SPI.h>


//variables
int lock = 0;
int colorIndex;
int startIndex;
bool trig = false;
uint32_t colors[] = {  // For rainbow wheel animation
  0xFF0000,   
  0xFF5500,
  0xFFFF00,
  0x00FF00,
  0x0000FF,
  0xFF00FF,
  0xFFFFFF,
  0x000000,
  0x000000,
  0x000000
};

float tempC; //temperature (in celsius)
#define STATE_COLD 0    // 3 states for temprature messure
#define STATE_MILD 50 
#define STATE_HOT 100 




//network
char auth[] = "******************************"; //enter your Auth Token you got from Blynk
char ssid[] = "******"; // enter your username wifi
char pass[] = "******"; // enter your password wifi
ESP8266 wifi(&EspSerial);




//clock alarm - Jingle Bells
// Jingle Bell tune
const int speed = 2;
const int red   = 130;
const int green = 80;
const int numNotes3 = 26;

int Jingle_Bell_tune[] = {                          
  NOTE_B4, NOTE_B4, NOTE_B4, 
  NOTE_B4, NOTE_B4, NOTE_B4,
  NOTE_B4, NOTE_D5, NOTE_G4, NOTE_A4,
  NOTE_B4, 0,
  NOTE_C5, NOTE_C5, NOTE_C5, NOTE_C5, 
  NOTE_C5, NOTE_B4, NOTE_B4, NOTE_B4, NOTE_B4, 
  NOTE_D5, NOTE_D5, NOTE_C5, NOTE_A4, 
  NOTE_G4};

int noteDurations3[] = {    
  4, 4, 2, 
  4, 4, 2, 
  4, 4, 3, 8,
  1, 4,
  4, 4, 3, 8, 
  4, 4, 4, 8, 8,
  4, 4, 4, 4, 
  1
  };



void setup() {
  CircuitPlayground.begin();
  Serial.begin(9600);
  EspSerial.begin(ESP8266_BAUD);
  delay(10);
  Blynk.begin(auth, wifi, ssid, pass);
  CircuitPlayground.setBrightness(255);
  startIndex = 0;
  CircuitPlayground.playTone(550, 550); //play when connected
  CircuitPlayground.setAccelRange(LIS3DH_RANGE_2_G); //Accelerometer define
}

void loop() {
  Blynk.run();
  tempC = CircuitPlayground.temperature();  //temperature (in celsius)
  //Serial.println("Temprature value:");
  //Serial.println(tempC);
  Wheel(trig);
  Blynk.virtualWrite(V5,tempC);
  if (tempC > 50){ //if the temprature is more then 50 Celsius, Email message sends.
    Blynk.email("tom.hatiel@gmail.com","Fire Alarm has started"); //Email messege
  }
  float silence = CircuitPlayground.mic.soundPressureLevel(50);  // check noise
  //Serial.println("Noise value:");
  //Serial.println(silence);
  if (silence >= 95){
    Blynk.email("tom.hatiel@gmail.com","A suspicious and loud noise in the house"); //Email messege
  }

}






//What to wear by weather outside
BLYNK_WRITE(V2){     
  delay(5000); //wait 5 seconds until measure
  int temp = CircuitPlayground.temperature();
  if (temp >= 30){
    temp = STATE_HOT;
  }else if (temp > 23 || temp < 29){
    temp = STATE_MILD;
  }else{
    temp = STATE_COLD;
  }
  
  switch(temp) {
    case STATE_COLD:
      handle_Cold();
      break;
    case STATE_MILD:
      handle_Mild();
      break;
    case STATE_HOT:
      handle_Hot();
      break;
  }
}

int handle_Cold() {
  Blynk.email("tom.hatiel@gmail.com","Dress recommendation","It's cold outside, wear long clothes"); // Email notification
  for (int j = 0; j < 3; ++j){  //Blink Blue light three times when triggered.
    for (int i = 0; i < 10; ++i) {
      CircuitPlayground.setPixelColor(i,0, 0, 255);  // Blue light
    }
    delay(2000);
    CircuitPlayground.clearPixels();
    delay(2000);
  }
}

int handle_Mild() {
  Blynk.email("tom.hatiel@gmail.com","Dress recommendation","The weather is nice outside, you can wear what you want"); // Email notification
  for (int j = 0; j < 3; ++j){  //Blink Green light three times when triggered.
    for (int i = 0; i < 10; ++i) {
      CircuitPlayground.setPixelColor(i,0, 255, 0);  // Green light
    }
    delay(2000);
    CircuitPlayground.clearPixels();
    delay(2000);
  }
}

int handle_Hot() {
  Blynk.email("tom.hatiel@gmail.com","Dress recommendation","It's very HOT outside, wear short clothes"); // Email notification
  for (int j = 0; j < 3; ++j){  //Blink Red light three times when triggered.
    for (int i = 0; i < 10; ++i) {  
      CircuitPlayground.setPixelColor(i, 255, 0 , 0); // Red light
    }
    delay(2000);
    CircuitPlayground.clearPixels();
    delay(2000);
  }
}



// Rainbow cycle
BLYNK_WRITE(V3) { 

  int z = param[2].asFloat();
 
  if (z < 0){
    trig = true;
  } else if ( z >= 0){
    trig = false;
  }
}

void Wheel(bool trig){  // Rainbow cycle
  if (trig == true){
    lock = 1;
    CircuitPlayground.clearPixels();
  // Loop through and set pixels
  colorIndex = startIndex;
  for (int pixel=0; pixel<10; pixel++) {
    CircuitPlayground.setPixelColor(pixel, colors[colorIndex]);
    colorIndex++;
    if (colorIndex > 9) colorIndex = 0;
  }

  // Increment start index into color array
  startIndex++;

  // Check value and reset if necessary
  if (startIndex > 9) startIndex = 0;

  // Wait a little bit so we don't spin too fast
  delay(ROTATION_RATE);
  }else if(trig == false){  // Smart Condition in order make it works :)
    lock = lock - 1;
    if (lock == 0){
      CircuitPlayground.clearPixels();
    }
  }
}

//Zebra pick color - light color mode
BLYNK_WRITE(V0) { 
  int r = param[0].asInt(); // assigning incoming value from pin V0 to a variable (Slider)
  int g = param[1].asInt(); // assigning incoming value from pin V0 to a variable (Slider)
  int b = param[2].asInt(); // assigning incoming value from pin V0 to a variable (Slider)
  CircuitPlayground.setBrightness(100);
  //Serial.println(pinValue);
  for (int i = 0; i < 10; ++i) {
        CircuitPlayground.setPixelColor(i,r, g, b); 
  }
}




//Jingle Bells alarm
BLYNK_WRITE(V9) {  

  for (int p = 0; p < 10; p++){
    CircuitPlayground.setPixelColor(p, 0, 0, 0);
  }

 for (int i = 0; i <= 5; i++){
    for (int thisNote = 0; thisNote < numNotes3; thisNote++) { // play notes of the melody

      if (Jingle_Bell_tune[thisNote] != 0){
        if (thisNote % 2){
          for (int p = 0; p <= 8; p=p+2){
            if (CircuitPlayground.motionZ() < -8){ //when cpx rotate 180 deg - the alarm stops
              CircuitPlayground.clearPixels();
              return;
            }
            CircuitPlayground.setPixelColor(p, red, 0, 0);//red
            CircuitPlayground.setPixelColor(p+1, 0, green, 0);
          }
        }
        else{
          for (int p = 0; p <= 8; p=p+2){
            if (CircuitPlayground.motionZ() < -8){ //when cpx rotate 180 deg - the alarm stops
              CircuitPlayground.clearPixels();
              return;
            }
            CircuitPlayground.setPixelColor(p, 0, green, 0);
            CircuitPlayground.setPixelColor(p+1, red, 0, 0);
          }
        }
      }
      
      int noteDuration = (1000 / speed) / noteDurations3[thisNote];
      CircuitPlayground.playTone(Jingle_Bell_tune[thisNote], noteDuration);

      int pauseBetweenNotes = noteDuration * 1.30;
      delay(pauseBetweenNotes);
    }
  }
    CircuitPlayground.clearPixels();



  
}
